imblearn.combine.SMOTETomek
===========================

.. currentmodule:: imblearn.combine

.. autoclass:: SMOTETomek

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SMOTETomek.__init__
      ~SMOTETomek.fit
      ~SMOTETomek.fit_sample
      ~SMOTETomek.get_params
      ~SMOTETomek.sample
      ~SMOTETomek.set_params
   
   

   
   
   